@@ -75,7 +75,7 @@ def update_html_docs_directory(html_docs_destination):
     (2) the config directory
     :return:
     """
-    link_url_prefix = "https://docs.aws.amazon.com/IAM/latest/UserGuide/"
+    link_url_prefix = "https://docs.aws.amazon.com/service-authorization/latest/reference/"
     initial_html_filenames_list = (
         get_links_from_base_actions_resources_conditions_page()
     )
@@ -157,7 +157,7 @@ def create_database(destination_directory, access_level_overrides_file):
     """
 
     # Create the docs directory if it doesn't exist
-    Path(os.path.join(destination_directory, "data", "docs")).mkdir(
+    Path(os.path.join(destination_directory, "docs")).mkdir(
         parents=True, exist_ok=True
     )
 
@@ -242,9 +242,13 @@ def create_database(destination_directory, access_level_overrides_file):
                     priv = ""
                     # Get the privilege
                     for link in cells[0].find_all("a"):
-                        if "href" not in link.attrs:
+                        if "href" not in link.attrs:  # pylint: disable=no-else-continue
                             # Skip the <a id='...'> tags
+                            api_documentation_link = None
                             continue
+                        else:
+                            api_documentation_link = link.attrs.get('href')
+                            print(api_documentation_link)
                         priv = chomp(link.text)
                     if priv == "":
                         priv = chomp(cells[0].text)
@@ -327,6 +331,7 @@ def create_database(destination_directory, access_level_overrides_file):
                         "description": description,
                         "access_level": access_level,
                         "resource_types": resource_types,
+                        "api_documentation_link": api_documentation_link
                     }
 
                     service_schema["privileges"][priv] = privilege_schema
@@ -398,9 +403,7 @@ def create_database(destination_directory, access_level_overrides_file):
                 service_prefix: service_schema
             }
             schema.update(this_service_schema)
-            # schema.append(service_schema)
 
-    # schema.sort(key=lambda x: x["prefix"])
     iam_definition_file = os.path.join(destination_directory, "iam-definition.json")
     with open(iam_definition_file, "w") as file:
         json.dump(schema, file, indent=4)
